GenericPack = {'Model name' : 'GenericPack',
               'Reference' : None,
               'dewcription' : 'Generic structure of a battery pack model.',
               'Battery pack efficiency' : None,
               'Number of modules' : None,
               'Number of cells series' : None,
               'Number of cells parallel' : None,
               'Battery module overhead' : None,
               'Battery pack overhead' : None}

ChevyVoltPack = {'Model name' : 'ChevyVoltPack',
                 'Reference' : 'G. L. Plett, Battery Management Systems, Volume 2: Equivalent Circuit Methods. in Artech House Power engineering series. Boston: Artech house, 2016.',
                 'Description' : 'Model of the battery pack of a Chevy Volt with parameters as described in Plett, 2016.',
                 'Battery pack efficiency' : 0.96,
                 'Number of modules' : 12,
                 'Number of cells in series' : 8,
                 'Number of cells in parallel' : 3,
                 'Battery module overhead' : 0.08,
                 'Battery pack overhead' : 0.1}